# Generated by Copilot
# Maintained by Dinesh Kumar C (https://github.com/Dinesh210805/blender-mcp)
# Forked from original work by Siddharth Ahuja (https://github.com/ahujasid/blender-mcp)

"""Blender integration through the Model Context Protocol."""

__version__ = "1.2.0"

# Expose key classes and functions for easier imports
from .connection import BlenderConnection, get_blender_connection, close_blender_connection
from .config import config, BlenderMCPConfig
from .exceptions import (
    BlenderMCPError,
    ConnectionError,
    ValidationError,
    SecurityError,
    TimeoutError,
    BlenderOperationError,
    AssetDownloadError,
)
from .models import MCPResponse, BlenderObjectInfo, AssetDownloadResult

__all__ = [
    "__version__",
    "BlenderConnection",
    "get_blender_connection", 
    "close_blender_connection",
    "config",
    "BlenderMCPConfig",
    "BlenderMCPError",
    "ConnectionError",
    "ValidationError", 
    "SecurityError",
    "TimeoutError",
    "BlenderOperationError",
    "AssetDownloadError",
    "MCPResponse",
    "BlenderObjectInfo",
    "AssetDownloadResult",
]
